@@ -727,7 +727,7 @@ service_xlock_finish (SecretService *service,
 /**
  * secret_service_lock:
  * @service: (allow-none): the secret service
- * @objects: (element-type GLib.DBusProxy): the items or collections to lock
+ * @objects: (element-type Gio.DBusProxy): the items or collections to lock
  * @cancellable: optional cancellation object
  * @callback: called when the operation completes
  * @user_data: data to pass to the callback
@@ -761,7 +761,7 @@ secret_service_lock (SecretService *service,
  * secret_service_lock_finish:
  * @service: (allow-none): the secret service
  * @result: asynchronous result passed to the callback
- * @locked: (out) (element-type GLib.DBusProxy) (transfer full) (allow-none):
+ * @locked: (out) (element-type Gio.DBusProxy) (transfer full) (allow-none):
  *          location to place list of items or collections that were locked
  * @error: location to place an error on failure
  *
@@ -788,9 +788,9 @@ secret_service_lock_finish (SecretService *service,
 /**
  * secret_service_lock_sync:
  * @service: (allow-none): the secret service
- * @objects: (element-type GLib.DBusProxy): the items or collections to lock
+ * @objects: (element-type Gio.DBusProxy): the items or collections to lock
  * @cancellable: optional cancellation object
- * @locked: (out) (element-type GLib.DBusProxy) (transfer full) (allow-none):
+ * @locked: (out) (element-type Gio.DBusProxy) (transfer full) (allow-none):
  *          location to place list of items or collections that were locked
  * @error: location to place an error on failure
  *
@@ -841,7 +841,7 @@ secret_service_lock_sync (SecretService *service,
 /**
  * secret_service_unlock:
  * @service: (allow-none): the secret service
- * @objects: (element-type GLib.DBusProxy): the items or collections to unlock
+ * @objects: (element-type Gio.DBusProxy): the items or collections to unlock
  * @cancellable: optional cancellation object
  * @callback: called when the operation completes
  * @user_data: data to pass to the callback
@@ -875,7 +875,7 @@ secret_service_unlock (SecretService *service,
  * secret_service_unlock_finish:
  * @service: (allow-none): the secret service
  * @result: asynchronous result passed to the callback
- * @unlocked: (out) (element-type GLib.DBusProxy) (transfer full) (allow-none):
+ * @unlocked: (out) (element-type Gio.DBusProxy) (transfer full) (allow-none):
  *            location to place list of items or collections that were unlocked
  * @error: location to place an error on failure
  *
@@ -902,9 +902,9 @@ secret_service_unlock_finish (SecretService *service,
 /**
  * secret_service_unlock_sync:
  * @service: (allow-none): the secret service
- * @objects: (element-type GLib.DBusProxy): the items or collections to unlock
+ * @objects: (element-type Gio.DBusProxy): the items or collections to unlock
  * @cancellable: optional cancellation object
- * @unlocked: (out) (element-type GLib.DBusProxy) (transfer full) (allow-none):
+ * @unlocked: (out) (element-type Gio.DBusProxy) (transfer full) (allow-none):
  *            location to place list of items or collections that were unlocked
  * @error: location to place an error on failure
  *
@@ -958,6 +958,7 @@ typedef struct {
 	SecretValue *value;
 	GHashTable *properties;
 	gboolean created_collection;
+	gboolean unlocked_collection;
 } StoreClosure;
 
 static void
@@ -1004,6 +1005,31 @@ on_store_keyring (GObject *source,
 	g_free (path);
 }
 
+static void
+on_store_unlock (GObject *source,
+                 GAsyncResult *result,
+                 gpointer user_data)
+{
+	GSimpleAsyncResult *async = G_SIMPLE_ASYNC_RESULT (user_data);
+	StoreClosure *store = g_simple_async_result_get_op_res_gpointer (async);
+	SecretService *service = SECRET_SERVICE (source);
+	GError *error = NULL;
+
+	secret_service_unlock_dbus_paths_finish (service, result, NULL, &error);
+	if (error == NULL) {
+		store->unlocked_collection = TRUE;
+		secret_service_create_item_dbus_path (service, store->collection_path,
+		                                      store->properties, store->value,
+		                                      SECRET_ITEM_CREATE_REPLACE, store->cancellable,
+		                                      on_store_create, g_object_ref (async));
+	} else {
+		g_simple_async_result_take_error (async, error);
+		g_simple_async_result_complete (async);
+	}
+
+	g_object_unref (async);
+}
+
 static void
 on_store_create (GObject *source,
                  GAsyncResult *result,
@@ -1033,6 +1059,12 @@ on_store_create (GObject *source,
 		g_hash_table_unref (properties);
 		g_error_free (error);
 
+	} else if (!store->unlocked_collection &&
+	           g_error_matches (error, SECRET_ERROR, SECRET_ERROR_IS_LOCKED)) {
+		const gchar *paths[2] = { store->collection_path, NULL };
+		secret_service_unlock_dbus_paths (service, paths, store->cancellable,
+		                                  on_store_unlock, g_object_ref (async));
+		g_error_free (error);
 	} else {
 		if (error != NULL)
 			g_simple_async_result_take_error (async, error);
